#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "friction_writer.hh"

template <class BitVector>
FrictionWriter<BitVector>::FrictionWriter(BitVector const &_boundaryNodes)
    : coefficientWriter("coefficients", std::fstream::out),
      displacementWriter("displacements", std::fstream::out),
      stateWriter("states", std::fstream::out),
      velocityWriter("velocities", std::fstream::out),
      boundaryNodes(_boundaryNodes) {}

template <class BitVector> FrictionWriter<BitVector>::~FrictionWriter() {
  stateWriter.close();
  displacementWriter.close();
  velocityWriter.close();
  coefficientWriter.close();
}

template <class BitVector>
template <class ScalarVector, class Vector>
void FrictionWriter<BitVector>::writeInfo(ScalarVector const &coefficient,
                                          ScalarVector const &alpha,
                                          Vector const &u, Vector const &v) {
  for (size_t i = 0; i < boundaryNodes.size(); ++i) {
    if (!boundaryNodes[i][0])
      continue;

    coefficientWriter << coefficient[i] << " ";
    displacementWriter << u[i][0] << " ";
    stateWriter << alpha[i][0] << " ";
    velocityWriter << v[i][0] << " ";
  }

  stateWriter << std::endl;
  displacementWriter << std::endl;
  velocityWriter << std::endl;
  coefficientWriter << std::endl;
}

#include "friction_writer_tmpl.cc"
